@@ -3,7 +3,6 @@ from botty_core import CompositeHandler
 from .buttons import CallbackButton, UrlButton
 from .handlers import (
     CommandHandler,
-    InlineMenuHandler,
     MessageHandler,
     QueryHandler,
     StartGroupHandler,
@@ -30,5 +29,4 @@ __all__ = [
     "CommandHandler",
     "StartHandler",
     "StartGroupHandler",
-    "InlineMenuHandler",
 ]
