@@ -1,3 +1,3 @@
-from .env import env
+from botty_core import env
 
 BOT_TOKEN = env.get("BOT_TOKEN")
