@@ -1,20 +1,24 @@
-from abc import ABC
-
-from botty_core.types import PTBHandler, Query
+from botty_core.types import PTBHandler, Query, User
 from telegram import ext
 
 from botty.buttons import CallbackButton
 from botty.errors import CallbackDataError
+from botty.keyboards import InlineKeyboard
 
-from .update import UpdateHandler
+from .message_or_query import MessageOrQueryHandler
 
 
-class QueryHandler(UpdateHandler, ABC):
-    def __init__(self, button: CallbackButton | None = None) -> None:
+class QueryHandler(MessageOrQueryHandler):
+    def __init__(
+        self,
+        button: CallbackButton | None = None,
+        reply_text: str | None = None,
+        reply_keyboard: InlineKeyboard | None = None,
+    ) -> None:
         callback_data = None if button is None else button.callback_data
         validate_callback_data(callback_data)
         self.on_callback_data = callback_data
-        super().__init__()
+        super().__init__(reply_text, reply_keyboard)
 
     def build(self) -> PTBHandler:
         return ext.CallbackQueryHandler(self.handle, self._filter)
@@ -32,6 +36,10 @@ class QueryHandler(UpdateHandler, ABC):
     def query(self) -> Query:
         return self.update.query
 
+    @property
+    def user(self) -> User:
+        return self.query.user
+
 
 def validate_callback_data(callback_data: object) -> None:
     if not isinstance(callback_data, str):
