@@ -11,3 +11,11 @@ class TextHandler(MessageHandler, ABC):
 
     def build(self) -> PTBHandler:
         return ext.MessageHandler(self.filters, self.handle)
+
+    @property
+    def text(self) -> str:
+        return self.message.text
+
+    @property
+    def text_words(self) -> list[str]:
+        return self.text.lower().split()
